@@ -11,7 +11,7 @@ import shutil
 from os import makedirs, remove, rename
 from os.path import isdir, join, basename, expanduser
 
-from apio import util
+from apio.util import get_home_dir, get_systype
 from apio.api import api_request
 from apio.resources import Resources
 from apio.profile import Profile
@@ -36,6 +36,8 @@ class Installer(object):
         self.forced_install = False
         self.valid_version = True
 
+        self.packages_dir = None
+
         self.resources = Resources()
         self.profile = Profile()
 
@@ -94,10 +96,10 @@ class Installer(object):
             if 'main_dir' in data.keys():
                 self.packages_dir = join(expanduser('~'), data['main_dir'])
             else:
-                self.packages_dir = join(util.get_home_dir(), 'packages')
+                self.packages_dir = join(get_home_dir(), 'packages')
 
     def install(self):
-        if self.version is None:
+        if self.packages_dir is None or self.version is None:
             click.secho(
                 'Error: No such package \'{0}\''.format(self.package),
                 fg='red')
@@ -107,8 +109,8 @@ class Installer(object):
                     self.package, self.version),
                 fg='red')
         else:
-            click.echo("Installing %s package:" % click.style(
-                self.package, fg="cyan"))
+            click.echo('Installing %s package:' % click.style(
+                self.package, fg='cyan'))
             if not isdir(self.packages_dir):
                 makedirs(self.packages_dir)
             assert isdir(self.packages_dir)
@@ -124,9 +126,8 @@ class Installer(object):
                     else:
                         self._unpack(dlpath, join(
                             self.packages_dir, self.package_name))
-            except Exception:
-                click.secho('Package {0} not found'.format(
-                    self.tarball), fg='red')
+            except Exception as e:
+                click.secho('Error: ' + str(e), fg='red')
             else:
                 if dlpath:
                     remove(dlpath)
@@ -151,8 +152,8 @@ class Installer(object):
                 fg='red')
         else:
             if isdir(join(self.packages_dir, self.package_name)):
-                click.echo("Uninstalling %s package" % click.style(
-                    self.package, fg="cyan"))
+                click.echo('Uninstalling %s package' % click.style(
+                    self.package, fg='cyan'))
                 shutil.rmtree(join(self.packages_dir, self.package_name))
                 click.secho(
                     """Package \'{}\' has been """
@@ -165,7 +166,7 @@ class Installer(object):
             self.profile.save()
 
     def _get_architecture(self):
-        return util.get_systype()
+        return get_systype()
 
     def _get_download_url(self, name, organization, tag, tarball):
         url = 'https://github.com/{0}/{1}/releases/download/{2}/{3}'.format(
@@ -202,8 +203,11 @@ class Installer(object):
         return version
 
     def _download(self, url):
-        if self.profile.check_package_version(self.package, self.version) or \
-           self.forced_install:
+        # Note: here we check only for the version of locally installed
+        # packages. For this reason we don't say what's the installation
+        # path.
+        if self.profile.check_package_version(self.package, self.version) \
+           or self.forced_install:
             fd = FileDownloader(url, self.packages_dir)
             click.secho('Download ' + basename(fd.get_filepath()))
             fd.start()
