@@ -7,8 +7,10 @@
 import os
 import json
 import click
+from collections import OrderedDict
 
 from apio.profile import Profile
+from apio.util import get_systype
 
 BOARDS_MSG = """
 Use `apio init --board <boardname>` for creating a new apio """ \
@@ -22,6 +24,17 @@ class Resources(object):
         self.boards = self._load_resource('boards')
         self.fpgas = self._load_resource('fpgas')
 
+        # Check available packages
+        self.packages = self._check_packages(self.packages)
+
+        # Sort resources
+        self.packages = OrderedDict(sorted(self.packages.items(),
+                                           key=lambda t: t[0]))
+        self.boards = OrderedDict(sorted(self.boards.items(),
+                                         key=lambda t: t[0]))
+        self.fpgas = OrderedDict(sorted(self.fpgas.items(),
+                                        key=lambda t: t[0]))
+
     def _load_resource(self, name):
         resource = None
         filepath = os.path.join(
@@ -31,6 +44,9 @@ class Resources(object):
             resource = json.loads(f.read())
         return resource
 
+    def get_package_release_name(self, package):
+        return self.packages[package]['release']['package_name']
+
     def list_packages(self, installed=True, notinstalled=True):
         """Return a list with all the installed/notinstalled packages"""
 
@@ -46,8 +62,10 @@ class Resources(object):
                 'version': None,
                 'description': self.packages[package]['description']
             }
-            if self.profile.check_package(package):
-                data['version'] = self.profile.get_package_version(package)
+            if self.profile.check_package(package,
+               self.get_package_release_name(package)):
+                data['version'] = self.profile.get_package_version(
+                    package, self.get_package_release_name(package))
                 installed_packages += [data]
             else:
                 notinstalled_packages += [data]
@@ -139,3 +157,17 @@ class Resources(object):
                 type=self.fpgas[fpga]['type'],
                 size=self.fpgas[fpga]['size'],
                 pack=self.fpgas[fpga]['pack']))
+
+    def _check_packages(self, packages):
+        filtered_packages = {}
+        for pkg in packages.keys():
+            check = True
+            release = packages[pkg]['release']
+            if 'available_archs' in release:
+                archs = release['available_archs']
+                check = False
+                for arch in archs:
+                    check |= get_systype() in arch
+            if check:
+                filtered_packages[pkg] = packages[pkg]
+        return filtered_packages
